# remirepo spec file for php-asm89-stack-cors, from:
#
# Fedora spec file for php-asm89-stack-cors
#
# Copyright (c) 2016-2017 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     asm89
%global github_name      stack-cors
%global github_version   1.1.0
%global github_commit    65ccbd455370f043c2e3b93482a3813603d68731

%global composer_vendor  asm89
%global composer_project stack-cors

# "php": ">=5.5.9"
%global php_min_ver 5.5.9
# "symfony/http-foundation": "~2.7|~3.0"
# "symfony/http-kernel": "~2.7|~3.0"
#     NOTE: Min version not 2.7 because autoloader required
%global symfony_min_ver 2.7.1
%global symfony_max_ver 4.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Cross-origin resource sharing library and stack middleware

Group:         Development/Libraries
License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}

# GitHub export does not include tests.
# Run php-asm89-stack-cors-get-source.sh to create full source.
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Autoloader
BuildRequires: php-fedora-autoloader-devel
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-composer(symfony/http-foundation) <  %{symfony_max_ver}
BuildRequires: php-composer(symfony/http-foundation) >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/http-kernel) <  %{symfony_max_ver}
BuildRequires: php-composer(symfony/http-kernel) >= %{symfony_min_ver}
## phpcompatinfo (computed from version 1.1.0)
##     <none>
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
Requires:      php-composer(symfony/http-foundation) >= %{symfony_min_ver}
Requires:      php-composer(symfony/http-foundation) <  %{symfony_max_ver}
Requires:      php-composer(symfony/http-kernel) >= %{symfony_min_ver}
Requires:      php-composer(symfony/http-kernel) <  %{symfony_max_ver}
# phpcompatinfo (computed from version 1.1.0)
#     <none>
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Library and middleware enabling cross-origin resource sharing for your
http-{foundation,kernel} using application. It attempts to implement the
W3C Candidate Recommendation [1] for cross-origin resource sharing.

Autoloader: %{phpdir}/Asm89/Stack/autoload-cors.php

[1] http://www.w3.org/TR/cors/


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Generate autoloader
%{_bindir}/phpab \
    --template fedora \
    --output src/Asm89/Stack/autoload-cors.php \
    src/

cat <<'AUTOLOAD' | tee -a src/Asm89/Stack/autoload-cors.php

\Fedora\Autoloader\Dependencies::required([
    [
        '%{phpdir}/Symfony3/Component/HttpFoundation/autoload.php',
        '%{phpdir}/Symfony/Component/HttpFoundation/autoload.php',
    ],
    [
        '%{phpdir}/Symfony3/Component/HttpKernel/autoload.php',
        '%{phpdir}/Symfony/Component/HttpKernel/autoload.php',
    ],
]);
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}
cp -rp src/Asm89 %{buildroot}%{phpdir}/


%check
%if %{with_tests}
: Upstream tests
RETURN_CODE=0
for PHP_EXEC in php php56 php70 php71 php72; do
    if [ "php" == "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC %{_bindir}/phpunit --verbose \
            --bootstrap %{buildroot}%{phpdir}/Asm89/Stack/autoload-cors.php \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%dir %{phpdir}/Asm89
%dir %{phpdir}/Asm89/Stack
     %{phpdir}/Asm89/Stack/autoload-cors.php
     %{phpdir}/Asm89/Stack/Cors.php
     %{phpdir}/Asm89/Stack/CorsService.php


%changelog
* Fri Apr 14 2017 Shawn Iwinski <shawn@iwin.ski> - 1.1.0-1
- Update to 1.1.0 (RHBZ #1441443)
- Add max versions to BuildRequires
- Switch autoloader to php-composer(fedora/autoloader)

* Fri Oct 21 2016 Remi Collet <remi@remirepo.net> - 1.0.0-1
- add backport stuff

* Sun Oct 09 2016 Shawn Iwinski <shawn@iwin.ski> - 1.0.0-1
- Initial package
